//=============================================================================
//
// file :        PushThread.h
//
// description : Include for the PushThread class.
//
//
//=============================================================================


#ifndef _PushThread_H
#define _PushThread_H

#include <memory>
#include <tango.h>
#include <cstdint>
#include <map>
#include <deque>
#include "AlarmData.h"
#include "AbortableThread.h"


namespace AlarmNotify_ns
{

    //=========================================================
    /**
     *	Shared data between DS and thread.
     */
    //=========================================================
    class PushThread: public AbortableThread
    {
        private:
            /**
             *	Manage data to write.
             */
            std::deque<std::unique_ptr<AlarmData>> events;
            /**
             *	Manage exceptions if any
             */
            vector<Tango::DevFailed> except;

            omni_mutex new_data_mutex;
            omni_condition new_data;

            size_t max_waiting;

            bool batch_insert = false;
            Tango::DeviceImpl *_device;
            std::unique_ptr<Tango::DeviceProxy> dp;
            string command;

        protected:

            void init_abort_loop() override;
            void run_thread_loop() override;
            void finalize_abort_loop() override;
            auto get_abort_loop_period() -> std::chrono::milliseconds override;
            
            void do_abort() override;

        public:
            /**
             *	Initialize the sub process parameters (name, domain, log_file).
             */
            PushThread(Tango::DeviceImpl *dev, const string& ds_name, const vector<string>& configuration);

            void push_back_cmd(const std::unique_ptr<AlarmData> argin);
            //void push_back_cmd(Tango::EventData argin);
            //	void remove_cmd();
            auto nb_cmd_waiting() -> size_t;
            auto get_next_cmds() -> std::vector<std::unique_ptr<AlarmData>>;

            auto get_max_waiting() -> size_t;
            void get_sig_list_waiting(vector<string> &);

    };


}// namespace

#endif	// _PushThread_H
